@@ -17,6 +17,7 @@ def main():
     init_config(conf_file)
     server = get_configs('server')
 
+
     alias = safe_get_host('server', 'alias')
     active_config = server.get('active_config', 'false')
 
@@ -25,10 +26,19 @@ def main():
         try:
             __import__(module)
         except ImportError:
-            raise Exception('Not imported the %s module' % module)
+            modules = module.split('.')
+            __import__(modules[0], globals(), locals(), modules[1])
 
     # 连结服务器
-    ztq_core.setup_redis('default', host=server['host'], port=int(server['port']), db=int(server['db']))
+    redis_host = os.environ.get('DB_PORT_6379_TCP_ADDR') # docker启动环境变量
+    if not redis_host:
+        redis_host = server['host']
+        redis_port = int(server['port'])
+        redis_db = int(server['db'])
+    else:
+        redis_port = 6379
+        redis_db = 0
+    ztq_core.setup_redis('default', host=redis_host, port=redis_port, db=redis_db)
 
     # 开启一个命令线程
     command_thread = CommandThread(worker_name=alias)
@@ -46,13 +56,12 @@ def main():
         queue_config = ztq_core.get_queue_config()
         # 如果配置有queues，自动启动线程监视
         job_threads = {}
-        queue_config = ztq_core.get_queue_config()
         for queue_name, sleeps in get_configs('queues').items():
-            queue_config[queue_name] = {'title': queue_name} # for ztq_app
             job_threads[queue_name] = [
                     {'interval': int(sleep)} for sleep in sleeps.split(',')
                     ]
-            queue_config[queue_name] = {'name':queue_name, 'title':queue_name, 'widget': 5}
+            if not queue_config.get(queue_name, []):
+                queue_config[queue_name] = {'name':queue_name, 'title':queue_name, 'widget': 5}
 
         init_job_threads(job_threads)
 
